==> sugarcrm-5.5.1.tbz: www/sugarcrm/modules/Charts/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/
/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
    'ERR_NO_OPPS' => 'Please create some Opportunities to see Opportunity graphs.',
    'LBL_ALL_OPPORTUNITIES' => 'Total amount of all opportunities is ',
    'LBL_CHART_TYPE' => 'Chart Type:',
    'LBL_CREATED_ON' => 'Last run on ',
    'LBL_DATE_END' => 'End Date:',
    'LBL_DATE_RANGE_TO' => 'to',
    'LBL_DATE_RANGE' => 'Date range is',
    'LBL_DATE_START' => 'Begin Date:',
    'LBL_EDIT' => 'Edit',
    'LBL_LEAD_SOURCE_BY_OUTCOME_DESC' => 'Shows cumulative opportunity amounts by selected lead source by outcome for selected users.  Outcome is based on whether the sales stage is Closed Won, Closed Lost, or any other value.',
    'LBL_LEAD_SOURCE_BY_OUTCOME' => 'All Opportunities By Lead Source By Outcome',
    'LBL_LEAD_SOURCE_FORM_DESC' => 'Shows cumulative opportunity amounts by selected lead source for selected users.',
    'LBL_LEAD_SOURCE_FORM_TITLE' => 'All Opportunities By Lead Source',
    'LBL_LEAD_SOURCE_OTHER' => 'Other',
    'LBL_LEAD_SOURCES' => 'Lead Sources:',
    'LBL_MODULE_NAME' => 'Dashboard',
    'LBL_MODULE_TITLE' => 'Dashboard: Home',
    'LBL_MONTH_BY_OUTCOME_DESC' => 'Shows cumulative opportunity amounts by month by outcome for selected users where the expected closed date is within the specified date range.  Outcome is based on whether the sales stage is Closed Won, Closed Lost, or any other value.',
    'LBL_NUMBER_OF_OPPS' => 'Number of Opportunities',
    'LBL_OPP_SIZE' => 'Opportunity size in',
    'LBL_OPP_THOUSANDS'=> 'K',
    'LBL_OPPS_IN_LEAD_SOURCE' => 'opportunities where lead source is',
    'LBL_OPPS_IN_STAGE' => ' where sales stage is',
    'LBL_OPPS_OUTCOME' => ' where outcome is',
    'LBL_OPPS_WORTH' => 'opportunities worth',
    'LBL_PIPELINE_FORM_TITLE_DESC' => 'Shows cumulative amounts by selected sales stages for your opportunities where the expected closed date is within the specified date range.',
    'LBL_CAMPAIGN_ROI_TITLE_DESC' => 'Shows campaign response by return on investment.',
    'LBL_REFRESH' => 'Refresh',
    'LBL_ROLLOVER_DETAILS' => 'Rollover a bar for details.',
    'LBL_ROLLOVER_WEDGE_DETAILS' => 'Rollover a wedge for details.',
    'LBL_SALES_STAGE_FORM_DESC' => 'Shows cumulative opportunity amounts by selected sales stages for selected users where the expected closed date is within the specified date range.',
    'LBL_SALES_STAGE_FORM_TITLE' => 'Pipeline By Sales Stage',
    'LBL_SALES_STAGES' => 'Sales Stages:',
    'LBL_TOTAL_PIPELINE' => 'Pipeline total is ',
    'LBL_USERS' => 'Users:',
    'LBL_YEAR_BY_OUTCOME' => 'Pipeline By Month By Outcome',
    'LBL_YEAR' => 'Year:',
    'LNK_NEW_ACCOUNT' => 'Create Account',
    'LNK_NEW_CALL' => 'Schedule Call',
    'LNK_NEW_CASE' => 'Create Case',
    'LNK_NEW_CONTACT' => 'Create Contact',
    'LNK_NEW_ISSUE' => 'Report Bug',
    'LNK_NEW_LEAD' => 'Create Lead',
    'LNK_NEW_MEETING' => 'Schedule Meeting',
    'LNK_NEW_NOTE' => 'Create Note or Attachment',
    'LNK_NEW_OPPORTUNITY' => 'Create Opportunity',
    'LNK_NEW_QUOTE' => 'Create Quote',
    'LNK_NEW_TASK' => 'Create Task',
    'NTC_NO_LEGENDS' => 'None',
    
    'LBL_TITLE' => 'Title: ',
    'LBL_MY_MODULES_USED_SIZE' => 'Access Count',
);


?>

==> sugarcrm-6.2.1.tbz: www/sugarcrm/modules/Charts/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
    'ERR_NO_OPPS' => 'Please create some Opportunities to see Opportunity graphs.',
    'LBL_ALL_OPPORTUNITIES' => 'Total amount of all opportunities is ',
    'LBL_CHART_TYPE' => 'Chart Type:',
    'LBL_CREATED_ON' => 'Last run on ',
	'LBL_CLOSE_DATE_START' => 'Expected Close Date - From:',
	'LBL_CLOSE_DATE_END'   => 'Expected Close Date - To:',
    'LBL_DATE_END' => 'End Date:',
    'LBL_DATE_RANGE_TO' => 'to',
    'LBL_DATE_RANGE' => 'Date range is',
    'LBL_DATE_START' => 'Begin Date:',
    'LBL_EDIT' => 'Edit',
    'LBL_LEAD_SOURCE_BY_OUTCOME_DESC' => 'Shows cumulative opportunity amounts by selected lead source by outcome for selected users.  Outcome is based on whether the sales stage is Closed Won, Closed Lost, or any other value.',
    'LBL_LEAD_SOURCE_BY_OUTCOME' => 'All Opportunities By Lead Source By Outcome',
    'LBL_LEAD_SOURCE_FORM_DESC' => 'Shows cumulative opportunity amounts by selected lead source for selected users.',
    'LBL_LEAD_SOURCE_FORM_TITLE' => 'All Opportunities By Lead Source',
    'LBL_LEAD_SOURCE_OTHER' => 'Other',
    'LBL_LEAD_SOURCES' => 'Lead Sources:',
    'LBL_MODULE_NAME' => 'Dashboard',
    'LBL_MODULE_TITLE' => 'Dashboard: Home',
    'LBL_MONTH_BY_OUTCOME_DESC' => 'Shows cumulative opportunity amounts by month by outcome for selected users where the expected closed date is within the specified date range.  Outcome is based on whether the sales stage is Closed Won, Closed Lost, or any other value.',
    'LBL_NUMBER_OF_OPPS' => 'Number of Opportunities',
    'LBL_OPP_SIZE' => 'Opportunity size in',
    'LBL_OPP_THOUSANDS'=> 'K',
    'LBL_OPPS_IN_LEAD_SOURCE' => 'opportunities where lead source is',
    'LBL_OPPS_IN_STAGE' => ' where sales stage is',
    'LBL_OPPS_OUTCOME' => ' where outcome is',
    'LBL_OPPS_WORTH' => 'opportunities worth',
    'LBL_PIPELINE_FORM_TITLE_DESC' => 'Shows cumulative amounts by selected sales stages for your opportunities where the expected closed date is within the specified date range.',
    'LBL_CAMPAIGN_ROI_TITLE_DESC' => 'Shows campaign response by return on investment.',
    'LBL_REFRESH' => 'Refresh',
    'LBL_ROLLOVER_DETAILS' => 'Rollover a bar for details.',
    'LBL_ROLLOVER_WEDGE_DETAILS' => 'Rollover a wedge for details.',
    'LBL_SALES_STAGE_FORM_DESC' => 'Shows cumulative opportunity amounts by selected sales stages for selected users where the expected closed date is within the specified date range.',
    'LBL_SALES_STAGE_FORM_TITLE' => 'Pipeline By Sales Stage',
    'LBL_SALES_STAGES' => 'Sales Stages:',
    'LBL_TOTAL_PIPELINE' => 'Pipeline total is ',
    'LBL_USERS' => 'Users:',
    'LBL_YEAR_BY_OUTCOME' => 'Pipeline By Month By Outcome',
    'LBL_YEAR' => 'Year:',
    'LNK_NEW_ACCOUNT' => 'Create Account',
    'LNK_NEW_CALL' => 'Log Call',
    'LNK_NEW_CASE' => 'Create Case',
    'LNK_NEW_CONTACT' => 'Create Contact',
    'LNK_NEW_ISSUE' => 'Report Bug',
    'LNK_NEW_LEAD' => 'Create Lead',
    'LNK_NEW_MEETING' => 'Schedule Meeting',
    'LNK_NEW_NOTE' => 'Create Note or Attachment',
    'LNK_NEW_OPPORTUNITY' => 'Create Opportunity',
    'LNK_NEW_QUOTE' => 'Create Quote',
    'LNK_NEW_TASK' => 'Create Task',
    'NTC_NO_LEGENDS' => 'None',
    
    'LBL_TITLE' => 'Title: ',
    'LBL_MY_MODULES_USED_SIZE' => 'Access Count',
);


?>
